@@ -72,11 +72,11 @@ class RouterFipPortForwardingMapping(object):
             if not self.managed_port_forwardings.get(port_forwarding.id):
                 continue
             self.managed_port_forwardings.pop(port_forwarding.id)
-            self.fip_port_forwarding[port_forwarding.floatingip_id].remove(
+            self.fip_port_forwarding[port_forwarding.floatingip_id].discard(
                 port_forwarding.id)
             if not self.fip_port_forwarding[port_forwarding.floatingip_id]:
                 self.fip_port_forwarding.pop(port_forwarding.floatingip_id)
-                self.router_fip_mapping[port_forwarding.router_id].remove(
+                self.router_fip_mapping[port_forwarding.router_id].discard(
                     port_forwarding.floatingip_id)
                 if not self.router_fip_mapping[port_forwarding.router_id]:
                     del self.router_fip_mapping[port_forwarding.router_id]
@@ -88,7 +88,7 @@ class RouterFipPortForwardingMapping(object):
 
     @lockutils.synchronized('port-forwarding-cache')
     def clear_by_fip(self, fip_id, router_id):
-        self.router_fip_mapping[router_id].remove(fip_id)
+        self.router_fip_mapping[router_id].discard(fip_id)
         if len(self.router_fip_mapping[router_id]) == 0:
             del self.router_fip_mapping[router_id]
         for pf_id in self.fip_port_forwarding[fip_id]:
@@ -169,7 +169,7 @@ class PortForwardingAgentExtension(l3_extension.L3AgentExtension):
                 iptables_manager.ipv4['nat'].add_chain(chain)
             iptables_manager.ipv4['nat'].add_rule(chain, rule, tag=rule_tag)
 
-    @coordination.synchronized('port-forwarding-{namespace}')
+    @coordination.synchronized('router-lock-ns-{namespace}')
     def _process_create(self, port_forwardings, ri, interface_name, namespace,
                         iptables_manager):
         if not port_forwardings:
@@ -301,7 +301,7 @@ class PortForwardingAgentExtension(l3_extension.L3AgentExtension):
                 context, [port_forwarding], ri, interface_name, namespace,
                 iptables_manager)
 
-    @coordination.synchronized('port-forwarding-{namespace}')
+    @coordination.synchronized('router-lock-ns-{namespace}')
     def _process_update(self, port_forwardings, iptables_manager,
                         interface_name, namespace):
         if not port_forwardings:
@@ -326,7 +326,7 @@ class PortForwardingAgentExtension(l3_extension.L3AgentExtension):
         iptables_manager.apply()
         self._store_local(port_forwardings, events.UPDATED)
 
-    @coordination.synchronized('port-forwarding-{namespace}')
+    @coordination.synchronized('router-lock-ns-{namespace}')
     def _process_delete(self, context, port_forwardings, ri, interface_name,
                         namespace, iptables_manager):
         if not port_forwardings:
