@@ -13,26 +13,20 @@
 #    under the License.
 
 import functools
-import re
+from unittest import mock
 
-import mock
-import netaddr
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants
 from oslo_config import cfg
 from oslo_utils import uuidutils
-from ovsdbapp.backend.ovs_idl import event
 from ovsdbapp.tests.functional import base as ovs_base
 
-from neutron.agent.linux import utils as linux_utils
 from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import utils
 from neutron.common import utils as n_utils
-from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.db import ovn_revision_numbers_db as db_rev
 from neutron.plugins.ml2.drivers.ovn.mech_driver import mech_driver
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import impl_idl_ovn
-from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovn_client
 from neutron.tests import base as tests_base
 from neutron.tests.functional import base
 
@@ -262,11 +256,11 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
         virt_port = self._create_port()
         virt_ip = virt_port['fixed_ips'][0]['ip_address']
 
-        # Create the master port with the VIP address already set in
+        # Create the primary port with the VIP address already set in
         # the allowed_address_pairs field
-        master = self._create_port(allowed_address=virt_ip)
+        primary = self._create_port(allowed_address=virt_ip)
 
-        # Assert the virt port has the type virtual and master is set
+        # Assert the virt port has the type virtual and primary is set
         # as parent
         self._check_port_type(virt_port['id'], ovn_const.LSP_TYPE_VIRTUAL)
         ovn_vport = self._find_port_row(virt_port['id'])
@@ -274,7 +268,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertEqual(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
 
         # Create the backport parent port
@@ -287,7 +281,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertIn(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
         self.assertIn(
             backup['id'],
@@ -295,7 +289,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
 
     @tests_base.unstable_test("bug 1865453")
     def test_virtual_port_update_address_pairs(self):
-        master = self._create_port()
+        primary = self._create_port()
         backup = self._create_port()
         virt_port = self._create_port()
         virt_ip = virt_port['fixed_ips'][0]['ip_address']
@@ -309,8 +303,8 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
         self.assertNotIn(ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY,
                          ovn_vport.options)
 
-        # Set the virt IP to the allowed address pairs of the master port
-        self._set_allowed_address_pair(master['id'], virt_ip)
+        # Set the virt IP to the allowed address pairs of the primary port
+        self._set_allowed_address_pair(primary['id'], virt_ip)
 
         # Assert the virt port is now updated
         self._check_port_type(virt_port['id'], ovn_const.LSP_TYPE_VIRTUAL),
@@ -319,7 +313,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertEqual(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
 
         # Set the virt IP to the allowed address pairs of the backup port
@@ -332,14 +326,14 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertIn(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
         self.assertIn(
             backup['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
 
-        # Remove the address pairs from the master port
-        self._unset_allowed_address_pair(master['id'])
+        # Remove the address pairs from the primary port
+        self._unset_allowed_address_pair(primary['id'])
 
         # Assert the virt port now only has the backup port as a parent
         self._check_port_type(virt_port['id'], ovn_const.LSP_TYPE_VIRTUAL),
@@ -365,13 +359,13 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
 
     @tests_base.unstable_test("bug 1865453")
     def test_virtual_port_created_after(self):
-        master = self._create_port(fixed_ip='10.0.0.11')
+        primary = self._create_port(fixed_ip='10.0.0.11')
         backup = self._create_port(fixed_ip='10.0.0.12')
         virt_ip = '10.0.0.55'
 
-        # Set the virt IP to the master and backup ports *before* creating
+        # Set the virt IP to the primary and backup ports *before* creating
         # the virtual port
-        self._set_allowed_address_pair(master['id'], virt_ip)
+        self._set_allowed_address_pair(primary['id'], virt_ip)
         self._set_allowed_address_pair(backup['id'], virt_ip)
 
         virt_port = self._create_port(fixed_ip=virt_ip)
@@ -384,7 +378,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertIn(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
         self.assertIn(
             backup['id'],
@@ -392,7 +386,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
 
     @tests_base.unstable_test("bug 1865453")
     def test_virtual_port_delete_parents(self):
-        master = self._create_port()
+        primary = self._create_port()
         backup = self._create_port()
         virt_port = self._create_port()
         virt_ip = virt_port['fixed_ips'][0]['ip_address']
@@ -406,8 +400,8 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
         self.assertNotIn(ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY,
                          ovn_vport.options)
 
-        # Set allowed address paris to the master and backup ports
-        self._set_allowed_address_pair(master['id'], virt_ip)
+        # Set allowed address paris to the primary and backup ports
+        self._set_allowed_address_pair(primary['id'], virt_ip)
         self._set_allowed_address_pair(backup['id'], virt_ip)
 
         # Assert the virtual port is correct
@@ -417,7 +411,7 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertIn(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
         self.assertIn(
             backup['id'],
@@ -426,18 +420,18 @@ class TestVirtualPorts(base.TestOVNFunctionalBase):
         # Delete the backup port
         self._delete('ports', backup['id'])
 
-        # Assert the virt port now only has the master port as a parent
+        # Assert the virt port now only has the primary port as a parent
         ovn_vport = self._find_port_row(virt_port['id'])
         self.assertEqual(ovn_const.LSP_TYPE_VIRTUAL, ovn_vport.type)
         self.assertEqual(
             virt_ip,
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_IP_KEY])
         self.assertEqual(
-            master['id'],
+            primary['id'],
             ovn_vport.options[ovn_const.LSP_OPTIONS_VIRTUAL_PARENTS_KEY])
 
-        # Delete the master port
-        self._delete('ports', master['id'])
+        # Delete the primary port
+        self._delete('ports', primary['id'])
 
         # Assert the virt port is not type virtual anymore and the virtual
         # port options are cleared
@@ -621,191 +615,8 @@ class TestExternalPorts(base.TestOVNFunctionalBase):
         self._test_external_port_update_switchdev(portbindings.VNIC_MACVTAP)
 
 
-class TestProvnetPorts(base.TestOVNFunctionalBase):
-
-    def setUp(self):
-        super(TestProvnetPorts, self).setUp()
-        self._ovn_client = self.mech_driver._ovn_client
-
-    def _find_port_row_by_name(self, name):
-        cmd = self.nb_api.db_find_rows(
-            'Logical_Switch_Port', ('name', '=', name))
-        rows = cmd.execute(check_error=True)
-        return rows[0] if rows else None
-
-    def create_segment(self, network_id, physical_network, segmentation_id):
-        segment_data = {'network_id': network_id,
-                        'physical_network': physical_network,
-                        'segmentation_id': segmentation_id,
-                        'network_type': 'vlan',
-                        'name': constants.ATTR_NOT_SPECIFIED,
-                        'description': constants.ATTR_NOT_SPECIFIED}
-        return self.segments_plugin.create_segment(
-            self.context, segment={'segment': segment_data})
-
-    def delete_segment(self, segment_id):
-        return self.segments_plugin.delete_segment(
-            self.context, segment_id)
-
-    def get_segments(self, network_id):
-        return self.segments_plugin.get_segments(
-            self.context, filters={'network_id': [network_id]})
-
-    def test_network_segments_localnet_ports(self):
-        n1 = self._make_network(
-                self.fmt, 'n1', True,
-                arg_list=('provider:network_type',
-                          'provider:segmentation_id',
-                          'provider:physical_network'),
-                **{'provider:network_type': 'vlan',
-                   'provider:segmentation_id': 100,
-                   'provider:physical_network': 'physnet1'})['network']
-        ovn_port = self._find_port_row_by_name(
-            utils.ovn_provnet_port_name(n1['id']))
-        # Assert that localnet port name is not based
-        # on network name.
-        self.assertIsNone(ovn_port)
-        seg_db = self.get_segments(n1['id'])
-        ovn_localnetport = self._find_port_row_by_name(
-            utils.ovn_provnet_port_name(seg_db[0]['id']))
-        self.assertEqual(ovn_localnetport.tag, [100])
-        self.assertEqual(ovn_localnetport.options['network_name'], 'physnet1')
-        seg_2 = self.create_segment(n1['id'], 'physnet2', '222')
-        ovn_localnetport = self._find_port_row_by_name(
-            utils.ovn_provnet_port_name(seg_2['id']))
-        self.assertEqual(ovn_localnetport.options['network_name'], 'physnet2')
-        self.assertEqual(ovn_localnetport.tag, [222])
-
-        # Delete segments and ensure that localnet
-        # ports are deleted.
-        self.delete_segment(seg_db[0]['id'])
-        ovn_localnetport = self._find_port_row_by_name(
-            utils.ovn_provnet_port_name(seg_db[0]['id']))
-        self.assertIsNone(ovn_localnetport)
-
-        # Make sure that other localnet port is not touched.
-        ovn_localnetport = self._find_port_row_by_name(
-            utils.ovn_provnet_port_name(seg_2['id']))
-        self.assertIsNotNone(ovn_localnetport)
-
-        # Delete second segment and validate that the
-        # second localnet port has been deleted.
-        self.delete_segment(seg_2['id'])
-        ovn_localnetport = self._find_port_row_by_name(
-            utils.ovn_provnet_port_name(seg_2['id']))
-        self.assertIsNone(ovn_localnetport)
-
-
-class TestMetadataPorts(base.TestOVNFunctionalBase):
-
-    def setUp(self, *args, **kwargs):
-        super().setUp(*args, **kwargs)
-        self._ovn_client = self.mech_driver._ovn_client
-        self.meta_regex = re.compile(
-            r'169.254.169.254/32,(\d+\.\d+\.\d+\.\d+)')
-
-    def _create_network_ovn(self, metadata_enabled=True):
-        self.mock_is_ovn_metadata_enabled = mock.patch.object(
-            ovn_conf, 'is_ovn_metadata_enabled').start()
-        self.mock_is_ovn_metadata_enabled.return_value = metadata_enabled
-        self.n1 = self._make_network(self.fmt, 'n1', True)
-        self.n1_id = self.n1['network']['id']
-
-    def _create_subnet_ovn(self, cidr, enable_dhcp=True):
-        _cidr = netaddr.IPNetwork(cidr)
-        res = self._create_subnet(self.fmt, self.n1_id, cidr,
-                                  enable_dhcp=enable_dhcp,
-                                  ip_version=_cidr.version)
-        return self.deserialize(self.fmt, res)['subnet']
-
-    def _list_ports_ovn(self, net_id=None):
-        res = self._list_ports(self.fmt, net_id=net_id)
-        return self.deserialize(self.fmt, res)['ports']
-
-    def _check_metadata_port(self, net_id, fixed_ip):
-        for port in self._list_ports_ovn(net_id=net_id):
-            if ovn_client.OVNClient.is_metadata_port(port):
-                self.assertEqual(net_id, port['network_id'])
-                if fixed_ip:
-                    self.assertIn(fixed_ip, port['fixed_ips'])
-                else:
-                    self.assertEqual([], port['fixed_ips'])
-                return port['id']
-
-        self.fail('Metadata port is not present in network %s or data is not '
-                  'correct' % self.n1_id)
-
-    def _check_subnet_dhcp_options(self, subnet_id, cidr):
-        # This method checks the DHCP options CIDR and returns, if exits, the
-        # metadata port IP address, included in the classless static routes.
-        dhcp_opts = self._ovn_client._nb_idl.get_subnet_dhcp_options(subnet_id)
-        self.assertEqual(cidr, dhcp_opts['subnet']['cidr'])
-        routes = dhcp_opts['subnet']['options'].get('classless_static_route')
-        if not routes:
-            return
-
-        match = self.meta_regex.search(routes)
-        if match:
-            return match.group(1)
-
-    def test_subnet_ipv4(self):
-        self._create_network_ovn(metadata_enabled=True)
-        subnet = self._create_subnet_ovn('10.0.0.0/24')
-        metatada_ip = self._check_subnet_dhcp_options(subnet['id'],
-                                                      '10.0.0.0/24')
-        fixed_ip = {'subnet_id': subnet['id'], 'ip_address': metatada_ip}
-        port_id = self._check_metadata_port(self.n1_id, fixed_ip)
-
-        # Update metatada port IP address to 10.0.0.5
-        data = {'port': {'fixed_ips': [{'subnet_id': subnet['id'],
-                                        'ip_address': '10.0.0.5'}]}}
-        req = self.new_update_request('ports', data, port_id)
-        req.get_response(self.api)
-        metatada_ip = self._check_subnet_dhcp_options(subnet['id'],
-                                                      '10.0.0.0/24')
-        self.assertEqual('10.0.0.5', metatada_ip)
-        fixed_ip = {'subnet_id': subnet['id'], 'ip_address': metatada_ip}
-        self._check_metadata_port(self.n1_id, fixed_ip)
-
-    def test_subnet_ipv4_no_metadata(self):
-        self._create_network_ovn(metadata_enabled=False)
-        subnet = self._create_subnet_ovn('10.0.0.0/24')
-        self.assertIsNone(self._check_subnet_dhcp_options(subnet['id'],
-                                                          '10.0.0.0/24'))
-        self.assertEqual([], self._list_ports_ovn(self.n1_id))
-
-    def test_subnet_ipv6(self):
-        self._create_network_ovn(metadata_enabled=True)
-        subnet = self._create_subnet_ovn('2001:db8::/64')
-        self.assertIsNone(self._check_subnet_dhcp_options(subnet['id'],
-                                                          '2001:db8::/64'))
-        self._check_metadata_port(self.n1_id, [])
-
-
-class TestAgentApi(base.TestOVNFunctionalBase):
-
-    def setUp(self):
-        super().setUp()
-        self.host = 'test-host'
-        self.controller_agent = self.add_fake_chassis(self.host)
-        self.plugin = self.mech_driver._plugin
-        agent = {'agent_type': 'test', 'binary': '/bin/test',
-                 'host': self.host, 'topic': 'test_topic'}
-        _, status = self.plugin.create_or_update_agent(self.context, agent)
-        self.test_agent = status['id']
-        mock.patch.object(self.mech_driver, 'ping_all_chassis',
-                          return_value=False).start()
-
-    def test_agent_show_non_ovn(self):
-        self.assertTrue(self.plugin.get_agent(self.context, self.test_agent))
-
-    def test_agent_show_ovn_controller(self):
-        self.assertTrue(self.plugin.get_agent(self.context,
-                                              self.controller_agent))
-
-
-class TestCreateDefaultDropPortGroup(ovs_base.FunctionalTestCase,
-                                     base.BaseLoggingTestCase):
+class TestCreateDefaultDropPortGroup(base.BaseLoggingTestCase,
+                                     ovs_base.FunctionalTestCase):
     schemas = ['OVN_Southbound', 'OVN_Northbound']
     PG_NAME = ovn_const.OVN_DROP_PORT_GROUP_NAME
 
@@ -856,52 +667,100 @@ class TestCreateDefaultDropPortGroup(ovs_base.FunctionalTestCase,
         self._test_pg_with_ports(expected_ports=[])
 
 
-class ConnectionInactivityProbeSetEvent(event.WaitEvent):
-    """Wait for a Connection (NB/SB) to have the inactivity probe set"""
+class TestProvnetPorts(base.TestOVNFunctionalBase):
 
-    ONETIME = False
+    def setUp(self):
+        super(TestProvnetPorts, self).setUp()
+        self._ovn_client = self.mech_driver._ovn_client
 
-    def __init__(self, target, inactivity_probe):
-        table = 'Connection'
-        events = (self.ROW_UPDATE,)
-        super().__init__(events, table, None)
-        self.event_name = "ConnectionEvent"
-        self.target = target
-        self.inactivity_probe = inactivity_probe
+    def _find_port_row_by_name(self, name):
+        cmd = self.nb_api.db_find_rows(
+            'Logical_Switch_Port', ('name', '=', name))
+        rows = cmd.execute(check_error=True)
+        return rows[0] if rows else None
 
-    def match_fn(self, event, row, old):
-        return row.target in self.target
+    def create_segment(self, network_id, physical_network, segmentation_id):
+        segment_data = {'network_id': network_id,
+                        'physical_network': physical_network,
+                        'segmentation_id': segmentation_id,
+                        'network_type': 'vlan',
+                        'name': constants.ATTR_NOT_SPECIFIED,
+                        'description': constants.ATTR_NOT_SPECIFIED}
+        return self.segments_plugin.create_segment(
+            self.context, segment={'segment': segment_data})
 
-    def run(self, event, row, old):
-        if (row.inactivity_probe and
-                row.inactivity_probe[0] == self.inactivity_probe):
-            self.event.set()
+    def delete_segment(self, segment_id):
+        return self.segments_plugin.delete_segment(
+            self.context, segment_id)
+
+    def get_segments(self, network_id):
+        return self.segments_plugin.get_segments(
+            self.context, filters={'network_id': [network_id]})
+
+    def test_network_segments_localnet_ports(self):
+        n1 = self._make_network(
+                self.fmt, 'n1', True,
+                arg_list=('provider:network_type',
+                          'provider:segmentation_id',
+                          'provider:physical_network'),
+                **{'provider:network_type': 'vlan',
+                   'provider:segmentation_id': 100,
+                   'provider:physical_network': 'physnet1'})['network']
+        ovn_port = self._find_port_row_by_name(
+            utils.ovn_provnet_port_name(n1['id']))
+        # Assert that localnet port name is not based
+        # on network name.
+        self.assertIsNone(ovn_port)
+        seg_db = self.get_segments(n1['id'])
+        ovn_localnetport = self._find_port_row_by_name(
+            utils.ovn_provnet_port_name(seg_db[0]['id']))
+        self.assertEqual(ovn_localnetport.tag, [100])
+        self.assertEqual(ovn_localnetport.options,
+                         {'network_name': 'physnet1'})
+        seg_2 = self.create_segment(n1['id'], 'physnet2', '222')
+        ovn_localnetport = self._find_port_row_by_name(
+            utils.ovn_provnet_port_name(seg_2['id']))
+        self.assertEqual(ovn_localnetport.options,
+                         {'network_name': 'physnet2'})
+        self.assertEqual(ovn_localnetport.tag, [222])
+
+        # Delete segments and ensure that localnet
+        # ports are deleted.
+        self.delete_segment(seg_db[0]['id'])
+        ovn_localnetport = self._find_port_row_by_name(
+            utils.ovn_provnet_port_name(seg_db[0]['id']))
+        self.assertIsNone(ovn_localnetport)
+
+        # Make sure that other localnet port is not touched.
+        ovn_localnetport = self._find_port_row_by_name(
+            utils.ovn_provnet_port_name(seg_2['id']))
+        self.assertIsNotNone(ovn_localnetport)
+
+        # Delete second segment and validate that the
+        # second localnet port has been deleted.
+        self.delete_segment(seg_2['id'])
+        ovn_localnetport = self._find_port_row_by_name(
+            utils.ovn_provnet_port_name(seg_2['id']))
+        self.assertIsNone(ovn_localnetport)
 
 
-class TestSetInactivityProbe(base.TestOVNFunctionalBase):
+class TestAgentApi(base.TestOVNFunctionalBase):
 
     def setUp(self):
         super().setUp()
-        self.dbs = [(ovn_conf.get_ovn_nb_connection(), 'ptcp:1000:1.2.3.4'),
-                    (ovn_conf.get_ovn_sb_connection(), 'ptcp:1001:1.2.3.4')]
-        linux_utils.execute(
-            ['ovn-nbctl', '--db=%s' % self.dbs[0][0],
-             'set-connection', self.dbs[0][1]], run_as_root=True)
-        linux_utils.execute(
-            ['ovn-sbctl', '--db=%s' % self.dbs[1][0],
-             'set-connection', self.dbs[1][1]], run_as_root=True)
+        self.host = 'test-host'
+        self.controller_agent = self.add_fake_chassis(self.host)
+        self.plugin = self.mech_driver._plugin
+        agent = {'agent_type': 'test', 'binary': '/bin/test',
+                 'host': self.host, 'topic': 'test_topic'}
+        _, status = self.plugin.create_or_update_agent(self.context, agent)
+        self.test_agent = status['id']
+        mock.patch.object(self.mech_driver, 'ping_all_chassis',
+                          return_value=False).start()
 
-    def test_1(self):
-        mock.patch.object(ovn_conf, 'get_ovn_ovsdb_probe_interval',
-                          return_value='2500').start()
-        nb_connection = ConnectionInactivityProbeSetEvent(self.dbs[0][1], 2500)
-        sb_connection = ConnectionInactivityProbeSetEvent(self.dbs[1][1], 2500)
-        self.nb_api.idl.notify_handler.watch_event(nb_connection)
-        self.sb_api.idl.notify_handler.watch_event(sb_connection)
-        with mock.patch.object(utils, 'connection_config_to_target_string') \
-                as mock_target:
-            mock_target.side_effect = [self.dbs[0][1], self.dbs[1][1]]
-            self.mech_driver._set_inactivity_probe()
+    def test_agent_show_non_ovn(self):
+        self.assertTrue(self.plugin.get_agent(self.context, self.test_agent))
 
-        self.assertTrue(nb_connection.wait())
-        self.assertTrue(sb_connection.wait())
+    def test_agent_show_ovn_controller(self):
+        self.assertTrue(self.plugin.get_agent(self.context,
+                                              self.controller_agent))
